@@ -3,13 +3,14 @@ use DBIx::Skinny::Schema;
 
 install_table job => schema {
     pk 'id';
-    columns qw/id func_id arg uniqkey enqueue_time grabbed_until run_after retry_cnt/;
+    columns qw/id func_id arg uniqkey enqueue_time grabbed_until run_after retry_cnt priority/;
 
     trigger pre_insert => callback {
         my ($class, $args) = @_;
         $args->{enqueue_time}  ||= time;
         $args->{grabbed_until} ||= 0;
         $args->{retry_cnt}     ||= 0;
+        $args->{priority}      ||= 0;
         $args->{run_after}     = time + ($args->{run_after}||0);
     };
 
@@ -38,14 +39,8 @@ install_table exception_log => schema {
 
 install_table job_status => schema {
     pk 'id';
-    columns qw/id func_id arg uniqkey status job_end_time/;
-
-    trigger pre_insert => callback {
-        my ($class, $args) = @_;
-        $args->{job_end_time} ||= time;
-    };
+    columns qw/id func_id arg uniqkey status job_start_time job_end_time/;
 };
 
-
 1;
 
